/*
  COPYRIGHT NOTICE
  Copyright (c) 2012  Scott C. Neu and Arthur W. Toga

  This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or (at your option) any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

package edu.ucla.loni.freesurfer;

/**
 * Tagged strings found in the MGH header.
 *
 * @version 16 March 2009
 */
public class MghTag
{
    /** Old colortable tag. */
    public static final int OLD_COLORTABLE = 1;

    /** Old user real ras tag. */
    public static final int OLD_USEREALRAS = 2;

    /** Command line tag. */
    public static final int CMDLINE = 3;

    /** Use real ras tag. */
    public static final int USEREALRAS = 4;

    /** Color table tag. */
    public static final int COLORTABLE = 5;

    /** GCA morph geom tag. */
    public static final int GCAMORPH_GEOM = 10;

    /** GCA morph type tag. */
    public static final int GCAMORPH_TYPE = 11;

    /** GCA morph labels tag. */
    public static final int GCAMORPH_LABELS = 12;

    /** Old surf geom tag. */
    public static final int OLD_SURF_GEOM = 20;

    /** Surf geom tag. */
    public static final int SURF_GEOM = 21;

    /** Old MGH transform tag. */
    public static final int OLD_MGH_XFORM = 30;

    /** MGH transform tag. */
    public static final int MGH_XFORM = 31;

    /** Group average surface area. */
    public static final int GROUP_AVG_SURFACE_AREA = 32;

    /** Tag code. */
    private int _code;

    /** Tag value. */
    private String _value;

    /**
     * Constructs an MGH Tag.
     *
     * @param code Tag code.
     * @param value Tag value.
     */
    public MghTag(int code, String value)
    {
	_code = code;
	_value = value;
    }

    /**
     * Gets the tag code.
     *
     * @return Code of the tag.
     */
    public int getCode()
    {
	return _code;
    }

    /**
     * Gets the tag value.
     *
     * @return Value of the tag.
     */
    public String getValue()
    {
	return _value;
    }
}
