/*
  COPYRIGHT NOTICE
  Copyright (c) 2012  Scott C. Neu and Arthur W. Toga

  This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or (at your option) any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

package edu.ucla.loni.freesurfer.plugin;

import edu.ucla.loni.imageio.AppletFriendlyIIOMetadataFormat;
import javax.imageio.ImageTypeSpecifier;

/**
 * IIO Metadata Format that describes the tree structure of metadata for the
 * Free Surfer "New" Curv Format.
 *
 * @version 29 January 2009
 */
public class CurvFormat extends AppletFriendlyIIOMetadataFormat
{
    /** Name of the native metadata format. */
    public static final String NATIVE_METADATA_FORMAT_NAME =
	"edu_ucla_loni_freesurfer_curv_1.0";

    /** Vertex count. */
    public static final String VERTEX_COUNT = "VertexCount";

    /** Face count. */
    public static final String FACE_COUNT = "FaceCount";

    /** Number of values per vertex. */
    public static final String VALS_PER_VERTEX = "ValsPerVertex";

    /** Single instance of the Curv Format. */
    private static CurvFormat _format = new CurvFormat();

    /** Constructs a Curv Format. */
    private CurvFormat()
    {
	// Create the root with no children
	super(NATIVE_METADATA_FORMAT_NAME, CHILD_POLICY_EMPTY);

	// Add the attributes
	addAttribute(NATIVE_METADATA_FORMAT_NAME, VERTEX_COUNT,
		     DATATYPE_INTEGER, true, null);
	addAttribute(NATIVE_METADATA_FORMAT_NAME, FACE_COUNT,
		     DATATYPE_INTEGER, true, null);
	addAttribute(NATIVE_METADATA_FORMAT_NAME, VALS_PER_VERTEX,
		     DATATYPE_INTEGER, true, null);
    }

    /**
     * Gets the instance of the Curv Format.
     *
     * @return Instance of the Curv Format.
     */
    public static CurvFormat getInstance()
    {
	return _format;
    }

    /**
     * Returns true if the element (and the subtree below it) is allowed to
     * appear in a metadata document for an image of the given type, defined by
     * an ImageTypeSpecifier.
     *
     * @param elementName The name of the element being queried.
     * @param imageType An ImageTypeSpecifier indicating the type of the image
     *                  that will be associated with the metadata.
     *
     * @return True if the node is meaningful for images of the given type.
     */
    public boolean canNodeAppear(String elementName,
				 ImageTypeSpecifier imageType)
    {
	// Not implemented
	return true;
    }
}
