/*
  COPYRIGHT NOTICE
  Copyright (c) 2012  Scott C. Neu and Arthur W. Toga

  This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or (at your option) any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

package edu.ucla.loni.jdicom;

/**
 * Data Dictionary of private DICOM Data Elements for Siemens scanners.
 *
 * @version 23 February 2011
 */
public class SiemensDataDictionary extends DataDictionary
{
    /** Single instance of the Siemens Data Dictionary. */
    private static DataDictionary _dictionary = new SiemensDataDictionary();

    /** Constructs a Siemens Data Dictionary. */
    private SiemensDataDictionary()
    {
    }

    /**
     * Gets the instance of the Siemens Data Dictionary.
     *
     * @return Single instance of the Siemens Data Dictionary.
     */
    public static DataDictionary getInstance()
    {
	return _dictionary;
    }

    /**
     * Determines if this Data Dictionary has private Data Elements from the
     * manufacturer.
     *
     * @param manufacturer Manufacturer.
     *
     * @return True if there are private Data Elements; false otherwise.
     */
    public static boolean isDictionaryFor(String manufacturer)
    {
	if (manufacturer == null) { return false; }
	return manufacturer.trim().toUpperCase().startsWith("SIEMENS");

    }

    /** Loads the registry of DICOM Data Elements. */
    protected void _loadRegistry()
    {
	// Group 0019 Elements
	_add("00190000", UL, "Group Length", VM_1);
	_add("00190010", LO, "", VM_1);
	_add("00191008", CS, "", VM_1);
	_add("0019000A", US, "NumberOfImagesInMosaic", VM_1);
	_add("0019000B", DS, "SliceMeasurementDuration", VM_1);
	_add("0019000C", IS, "B_value", VM_1);
	_add("0019000D", CS, "DiffusionDirectionality", VM_1);
	_add("0019000E", FD, "DiffusionGradientDirection", "3");
	_add("0019000F", SH, "GradientMode", VM_1);
	_add("0019100B", DS, "", VM_1);
	_add("0019100D", CS, "", VM_1);
	_add("00191012", SL, "", VM_1_N);
	_add("00191013", SL, "", VM_1_N);
	_add("00191014", IS, "", VM_1_N);
	_add("00191015", FD, "", VM_1_N);
	_add("00191016", DS, "", VM_1);
	_add("00191017", DS, "", VM_1);
	_add("00191018", IS, "", VM_1);
	_add("00191027", FD, "B_matrix", "6");
	_add("00191028", FD, "BandwidthPerPixelPhaseEncode", VM_1);

	// Group 0029 Elements
	_add("00290000", UL, "Group Length", VM_1);
	_add("00291008", CS, "CSA Image Header Type", VM_1);
	_add("00291009", LO, "CSA Image Header Version", VM_1);
	_add("00291010", OB, "CSA Image Header Info", VM_1);
	_add("00291018", CS, "CSA Series Header Type", VM_1);
	_add("00291019", LO, "CSA Series Header Version", VM_1);
	_add("00291020", OB, "CSA Series Header Info", VM_1);
    }
}
