/*
  COPYRIGHT NOTICE
  Copyright (c) 2012  Scott C. Neu and Arthur W. Toga

  This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or (at your option) any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

package edu.ucla.loni.jdicom.plugin.node;

import java.util.HashMap;
import java.util.Iterator;

/**
 * Iterator for a set of Data Element Nodes.
 *
 * @version 5 April 2010
 */
public class DataElementNodeIterator implements Iterator
{
    /** Iterator of Data Elements. */
    private Iterator _iterator;

    /** Mapping from Data Element tags to Data Element Nodes. */
    private HashMap _tagsToElements;

    /** Last Data Element Node returned by the iteration. */
    private DataElementNode _lastElement;

    /**
     * Constructs a Data Element Node Iterator.
     *
     * @param iterator Iterator of Data Elements.
     * @param tagsToElements Mapping from Data Element tags to Data Elements.
     */
    public DataElementNodeIterator(Iterator iterator, HashMap tagsToElements)
    {
	_iterator = iterator;
	_tagsToElements = tagsToElements;
    }

    /**
     * Determines if the iteration has more elements.
     *
     * @return True if the iteration has more elements; false otherwise.
     */
    public boolean hasNext()
    {
	return _iterator.hasNext();
    }

    /**
     * Gets the next element in the iteration.
     *
     * @return Next element in the iteration.
     *
     * @throws NoSuchElementException If the iteration has no more elements.
     */
    public Object next()
    {
	_lastElement = (DataElementNode)_iterator.next();
	return _lastElement;
    }

    /**
     * Removes from the underlying collection the last element returned by the
     * iterator.
     *
     * @throws IllegalStateException If the next() method has not been called.
     * @throws IllegalStateException If the remove() method has already been
     *                               called after the last call to the next()
     *                               method.
     */
    public void remove()
    {
	// Remove the last Data Element Node
	_iterator.remove();

	// Update the hashmap
	_tagsToElements.remove( _lastElement.getTag() );
    }
}
