/*
  COPYRIGHT NOTICE
  Copyright (c) 2012  Scott C. Neu and Arthur W. Toga

  This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or (at your option) any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

package edu.ucla.loni.jdicom.plugin.node;

import java.util.Iterator;

/**
 * Iterator for a set of DICOM Nodes.
 *
 * @version 5 April 2010
 */
public class DicomNodeIterator implements Iterator
{
    /** Iterator of DICOM Nodes. */
    private Iterator _iterator;

    /** Last DICOM Node returned by the iteration. */
    private DicomNode _lastNode;

    /**
     * Constructs a DICOM Node Iterator.
     *
     * @param iterator Iterator of DICOM Nodes.
     */
    public DicomNodeIterator(Iterator iterator)
    {
	_iterator = iterator;
    }

    /**
     * Determines if the iteration has more elements.
     *
     * @return True if the iteration has more elements; false otherwise.
     */
    public boolean hasNext()
    {
	return _iterator.hasNext();
    }

    /**
     * Gets the next element in the iteration.
     *
     * @return Next element in the iteration.
     *
     * @throws NoSuchElementException If the iteration has no more elements.
     */
    public Object next()
    {
	_lastNode = (DicomNode)_iterator.next();
	return _lastNode;
    }

    /**
     * Removes from the underlying collection the last element returned by the
     * iterator.
     *
     * @throws IllegalStateException If the next() method has not been called.
     * @throws IllegalStateException If the remove() method has already been
     *                               called after the last call to the next()
     *                               method.
     */
    public void remove()
    {
	// Remove the last DICOM Node
	_iterator.remove();

	// Connect the siblings
	DicomNode prevNode = (DicomNode)_lastNode.getPreviousSibling();
	DicomNode nextNode = (DicomNode)_lastNode.getNextSibling();
	if (prevNode != null) { prevNode._setNextSibling(nextNode); }
	if (nextNode != null) { nextNode._setPreviousSibling(prevNode); }

	// Erase references of the last DICOM Node
	_lastNode._setParent(null);
	_lastNode._setPreviousSibling(null);
	_lastNode._setNextSibling(null);
    }
}
