/*
  COPYRIGHT NOTICE
  Copyright (c) 2012  Scott C. Neu and Arthur W. Toga

  This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or (at your option) any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

package edu.ucla.loni.jdicom.plugin.write;

import edu.ucla.loni.jdicom.DataSet;
import edu.ucla.loni.jdicom.plugin.OutputStreamAdapter;
import java.io.IOException;
import java.io.OutputStream;
import javax.imageio.stream.ImageOutputStream;

/**
 * DICOM Block for the image metadata (DICOM tag 5200,9230).
 *
 * @version 16 March 2011
 */
public class ImageMetadata extends DicomBlock
{
    /** Output Stream implementation for the image metadata. */
    private ImageMetadataOS _imageMetadataOS;

    /**
     * Constructs an Image Metadata that writes to the output stream.
     *
     * @param outputStream Output stream where the block is written.
     * @param transferSyntax Transfer syntax that determines the encoding.
     *
     * @throws IOException If an error occurs during writing.
     */
    public ImageMetadata(ImageOutputStream outputStream, String transferSyntax)
	throws IOException
    {
	super(outputStream, transferSyntax);

	// Initialize the Output Stream implementation
	OutputStream os = new OutputStreamAdapter(outputStream);
	_imageMetadataOS = new ImageMetadataOS(os, transferSyntax);

	// Update the size
	_setSize();
    }

    /**
     * Adds the data set to the end of the block.
     *
     * @param dataSet Data Set containing the Data Elements to write.
     *
     * @throws IOException If an error occurs during writing.
     */
    public void append(DataSet dataSet) throws IOException
    {
	_imageMetadataOS.append(dataSet);

	// Update the size
	_setSize();
    }

    /**
     * Finishes writing the block.
     *
     * @throws IOException If an error occurs during writing.
     */
    public void finish() throws IOException
    {
	_imageMetadataOS.finish();

	// Update the size
	_setSize();
    }
}
