/*
  COPYRIGHT NOTICE
  Copyright (c) 2012  Scott C. Neu and Arthur W. Toga

  This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or (at your option) any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

package edu.ucla.loni.nrrd;

/**
 * NRRD Header Element for a field specification.
 *
 * @version 25 October 2010
 */
public class Field extends NrrdHeaderElement
{
    /** Information describing the field. */
    private String _descriptor;

    /**
     * Constructs a Field.
     *
     * @param identifier Identifier for the field.
     * @param descriptor Information describing the field.
     *
     * @throws IllegalArgumentException If the identifier is the empty string.
     * @throws NullPointerException If the identifier is null.
     */
    public Field(String identifier, String descriptor)
    {
	super(identifier);

	// Check the identifier
	if ( "".equals(identifier) ) {
	    throw new IllegalArgumentException("Empty identifier");
	}

	// Convert case-insensitive identifier to lower-case
	_name = _name.toLowerCase();
	_descriptor = descriptor;
    }

    /**
     * Gets the identifier.
     *
     * @return Identifier for the field.
     */
    public String getIdentifier()
    {
	return _name;
    }

    /**
     * Gets the descriptor.
     *
     * @return Information describing the field.
     */
    public String getDescriptor()
    {
	return _descriptor;
    }

    /**
     * Determines if this object is equal to the given object.
     *
     * @param obj Object to compare to.
     *
     * @return True if this object is equal to the given object; false o/w.
     */
    public boolean equals(Object obj)
    {
	// Must be a Field
	if (obj instanceof Field) { return super.equals(obj); }
	return false;
    }

    /**
     * Gets a string representation of this Object.
     *
     * @return String representation of this Object.
     */
    public String toString()
    {
	return "FIELD " + _name + " = \"" + _descriptor + "\"";
    }
}
