/*
  COPYRIGHT NOTICE
  Copyright (c) 2012  Scott C. Neu and Arthur W. Toga

  This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or (at your option) any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

package edu.ucla.loni.nrrd;

/**
 * NRRD Header Element for a key and value pair.
 *
 * @version 25 October 2010
 */
public class KeyValuePair extends NrrdHeaderElement
{
    /** Value. */
    private String _value;

    /**
     * Constructs a Key-Value Pair.
     *
     * @param key Key.
     * @param value Value.
     *
     * @throws IllegalArgumentException If the key is not at least 1 character.
     */
    public KeyValuePair(String key, String value)
    {
	super(key);

	// Check the key
	if (key.length() < 1) {
	    throw new IllegalArgumentException("Illegal key");
	}

	// Convert null values to empty strings
	_value = value;
	if (_value == null) { _value = ""; }
    }

    /**
     * Gets the key.
     *
     * @return Key.
     */
    public String getKey()
    {
	return _name;
    }

    /**
     * Gets the value.
     *
     * @return Value.
     */
    public String getValue()
    {
	return _value;
    }

    /**
     * Determines if this object is equal to the given object.
     *
     * @param obj Object to compare to.
     *
     * @return True if this object is equal to the given object; false o/w.
     */
    public boolean equals(Object obj)
    {
	// Must be a Key-Value Pair
	if (obj instanceof KeyValuePair) { return super.equals(obj); }
	return false;
    }

    /**
     * Gets a string representation of this Object.
     *
     * @return String representation of this Object.
     */
    public String toString()
    {
	return "KEY-VALUE " + _name + " = \"" + _value + "\"";
    }
}
