/*
  COPYRIGHT NOTICE
  Copyright (c) 2012  Scott C. Neu and Arthur W. Toga

  This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or (at your option) any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

package edu.ucla.loni.nrrd;

/**
 * Element of an NRRD header.
 *
 * @version 25 October 2010
 */
public class NrrdHeaderElement
{
    /** Name of the element. */
    protected String _name;

    /**
     * Constructs an NRRD Header Element.
     *
     * @param name Name of the element.
     *
     * @throws NullPointerException If the name is null.
     */
    protected NrrdHeaderElement(String name)
    {
	// Check the name
	if (name == null) { throw new NullPointerException(name); }

	_name = name;

    }

    /**
     * Gets a hash code for the object.
     *
     * @return Hash code for the object.
     */
    public int hashCode()
    {
	return _name.hashCode();
    }

    /**
     * Determines if this object is equal to the given object.
     *
     * @param obj Object to compare to.
     *
     * @return True if this object is equal to the given object; false o/w.
     */
    public boolean equals(Object obj)
    {
	// Header Element
	if (obj instanceof NrrdHeaderElement) {
	    return _name.equals( ((NrrdHeaderElement)obj)._name );
	}

	return super.equals(obj);
    }
}
