/*
  COPYRIGHT NOTICE
  Copyright (c) 2012  Scott C. Neu and Arthur W. Toga

  This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or (at your option) any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

package edu.ucla.loni.nrrd.plugin;

import edu.ucla.loni.blobio.BlobWriter;
import edu.ucla.loni.blobio.spi.BlobWriterSpi;
import edu.ucla.loni.imageio.DualImageOutputStream;
import java.util.Locale;
import java.util.Vector;
import javax.imageio.stream.ImageOutputStream;

/**
 * Blob Writer SPI (Service Provider Interface) for the NRRD image format.
 *
 * @version 2 November 2010
 */
public class NrrdBlobWriterSpi extends BlobWriterSpi
{
    /** Name of the vendor who supplied this plug-in. */
    private static String _vendorName = "Laboratory of Neuro Imaging (LONI)";

    /** Version of this plug-in. */
    private static String _version = "1.0";

    /** Names of the formats read by this plug-in. */
    private static String[] _formatNames = {"nrrd", "NRRD"};

    /** Names of commonly used suffixes for files in the supported formats. */
    private static String[] _fileSuffixes = {"nrrd", "NRRD", "nhdr", "NHDR",
					     "raw", "RAW", "raw.gz", "RAW.GZ"};

    /** MIME types of supported formats. */
    private static String[] _mimeTypes = {"image/nhdr", "image/nrrd"};

    /** Name of the associated Blob Writer. */
    private static String _writer = NrrdBlobWriter.class.getName();

    /** Allowed output type classes for the plugin-in. */
    private static Class[] _outputTypes = {DualImageOutputStream.class,
					   ImageOutputStream.class,
					   Vector.class};

    /** Names of the associated Blob Reader SPI's. */
    private static String[] _readSpis = {NrrdBlobReaderSpi.class.getName()};

    /** Constructs an NRRD Blob Writer SPI. */
    public NrrdBlobWriterSpi()
    {
	super(_vendorName, _version, _formatNames, _fileSuffixes, _mimeTypes,
	      _writer, _outputTypes, _readSpis,
	      NrrdMetadataFormat.NATIVE_METADATA_FORMAT_NAME,
	      NrrdMetadataFormat.class.getName());
    }

    /**
     * Returns a brief, human-readable description of this service provider and
     * its associated implementation.
     *
     * @param locale Locale for which the return value should be localized.
     *
     * @return Description of this service provider.
     */
    public String getDescription(Locale locale)
    {
	NrrdImageWriterSpi imageWriterSpi = new NrrdImageWriterSpi();
	return imageWriterSpi.getDescription(locale);
    }

    /**
     * Returns an instance of the Blob Writer implementation associated with
     * this service provider.  The returned object will initially be in an
     * initial state as if its reset method had been called.
     *
     * @return A Blob Writer instance.
     */
    public BlobWriter createWriterInstance()
    {
	return new NrrdBlobWriter(this);
    }
}
