/*
  COPYRIGHT NOTICE
  Copyright (c) 2012  Scott C. Neu and Arthur W. Toga

  This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or (at your option) any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

package edu.ucla.loni.nrrd.plugin;

import java.util.ListResourceBundle;

/**
 * List Resource Bundle that provides descriptions for NRRD elements.
 *
 * @version 25 October 2010
 */
public class NrrdMetadataFormatResources extends ListResourceBundle
{
    /** Constructs an NRRD Metadata Format Resources. */
    public NrrdMetadataFormatResources()
    {
    }

    /**
     * Gets the contents of the Resource Bundle.
     *
     * @return Object array of the contents, where each item of the array is a
     *         pair of Objects.  The first element of each pair is the key,
     *         which must be a String, and the second element is the value
     *         associated with that key.
     */
    public Object[][] getContents()
    {
	String main = NrrdMetadataFormat.NATIVE_METADATA_FORMAT_NAME;
	String fields = NrrdMetadataFormat.FIELDS;
	String keys = NrrdMetadataFormat.KEYS;

	Object[][] contents = {

	    // Node name, followed by description
	    {fields, "Field specifications."},
	    {keys, "Key-Value pairs."},
	    {"DWMRI_gradient", "Diffusion gradient direction."},

	    // Node name + "/" + attribute name, followed by description
	    {main + "/" + NrrdMetadataFormat.MAGIC, "Magic number."},

	    {fields + "/content",
	     "Very concise textual description of the information."},
	    {fields + "/type", "Data type."},
	    {fields + "/dimension", "Number of image dimensions."},
	    {fields + "/space",
	     "Orientation of the raster grid relative to a surrounding space."},
	    {fields + "/sizes",
	     "Image dimensions ordered from fastest to slowest."},
	    {fields + "/space--directions",
	     "Both the direction and spacing associated with each axis of " +
	     "the array."},
	    {fields + "/space--origin",
	     "Location of the center of the first sample in the array."},
	    {fields + "/space--units", "Unit names of spacial axes."},
	    {fields + "/centerings",
	     "How information along each axis is centered."},
	    {fields + "/kinds", "Labels given to each axis (space, time,...)."},
	    {fields + "/endian", "Byte ordering of the current platform."},
	    {fields + "/encoding", "Data encoding and compression."},
	    {fields + "/measurement--frame",
	     "Defines the relationship between the frame associated with the " +
	     "coordinates of some non-scalar quantities, and the world space " +
	     "in which the image orientation is defined."},
	    {fields + "/data--file", "Name of the data file."},

	    {keys + "/modality", "Modality."},
	    {keys + "/DWMRI_b-value", "Magnetic field."},

	    // Node name + "/" + attribute name, followed by description
	    {"*/" + NrrdMetadataFormat.KEY, "Key."},
	    {"*/" + NrrdMetadataFormat.VALUE, "Value."}
	};

	return contents;
    }
}






